function [mesh] = createmesh(DIM,M)
%CREATEMESH creates a regular mesh of [0,1]^DIM with M-1 inner nodes in every dir.
%   DIM = 2/3 is the spatial dimension
%   The function creates a uniform mesh with mesh-size h = 1/M
%   and coordinates 0*h, 1*h, ..., M*h
%   Only the inner points are stored (no points on the boundary)
%   So: (M-1) points in each direction a total of N=(M-1)^DIM points
%   The mesh is a matrix of dimension N x DIM
%   mesh(i,1), mesh(i,2) is the 2d-coordinate of point i,
%   mesh(i,1), mesh(i,2), mesh(i,3) is the 3d-coordinate of point i
%   Sorting: point i is X_i = (x_k,y_l) with i = k + (M-1) l
%     in 3d: point i is X_i = (x_k,y_l,z_m][\) with i = k+(M-1) l + (M-1)^2 m
h=1/M;
N=(M-1)^DIM;
mesh=zeros(N,DIM);
if DIM==1
    mesh = h*[1:1:M-1];
elseif DIM==2
    mesh(:,1) = repmat(h*[1:1:M-1]',M-1,1);
    mesh(:,2) = repelem(h*[1:1:M-1]',M-1,1);
elseif DIM==3
    mesh(:,1) = repmat(h*[1:1:M-1]',(M-1)*(M-1),1);
    mesh(:,2) = repmat(repelem(h*[1:1:M-1]',(M-1),1),M-1,1);
    mesh(:,3) = repelem(h*[1:1:M-1]',(M-1)*(M-1),1);
end



